==> notolog-0.9.1b3.tar.gz: notolog-0.9.1b3/notolog/lexemes/fr/settings_dialog.py <==
# French lexemes settings_dialog.py
lexemes = {
    # Paramètres
    "window_title": "Paramètres",

    "button_close": "Fermer",

    "tab_general": "Général",
    "tab_editor_config": "Éditeur",
    "tab_viewer_config": "Visualiseur",
    "tab_ai_config": "Config IA",

    "general_app_config_label": "Configuration de l'application",
    "general_app_language_label": "Langue",
    "general_app_language_combo_placeholder_text": "Choisir une langue",
    "general_app_language_combo_accessible_description": "Langue de l'interface de l'application",
    "general_app_theme_label": "Thème",
    "general_app_theme_combo_placeholder_text": "Choisir un thème",
    "general_app_theme_combo_accessible_description": "Thème de l'interface de l'application",
    "general_app_main_menu_label": "Menu Principal",
    "general_app_main_menu_checkbox": "Afficher le menu principal",
    "general_app_main_menu_checkbox_accessible_description": "Afficher le menu déroulant principal de l'application",
    "general_app_font_size_label": "Taille de police : {size}pt",
    "general_app_font_size_slider_accessible_description": "Ajuster la taille de la police globale de l'application",

    "general_statusbar_label": "Barre de statut",
    "general_statusbar_show_global_cursor_position_checkbox": "Afficher la position globale du curseur",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "Afficher la position globale du curseur dans la barre de statut",

    "editor_config_label": "Configuration de l'éditeur",
    "editor_config_show_line_numbers_checkbox": "Afficher les numéros de ligne",
    "editor_config_show_line_numbers_checkbox_accessible_description": "Afficher les numéros de ligne dans l'éditeur",

    "viewer_config_label": "Configuration du visualiseur",
    "viewer_config_process_emojis_checkbox": "Convertir les emojis de texte en graphiques",
    "viewer_config_process_emojis_checkbox_accessible_description":
        "Convertir les emojis de texte en représentations graphiques",
    "viewer_config_highlight_todos_checkbox": "Mettre en évidence les TODO",
    "viewer_config_highlight_todos_checkbox_accessible_description": "Souligner les balises TODO dans le texte",
    "viewer_config_open_link_confirmation_checkbox": "Demander confirmation avant d'ouvrir les liens",
    "viewer_config_open_link_confirmation_checkbox_accessible_description":
        "Demander une confirmation avant d'ouvrir des liens",
    "viewer_config_save_resources_checkbox": "Enregistrer automatiquement les images externes sur le disque",
    "viewer_config_save_resources_checkbox_accessible_description":
        "Enregistre automatiquement des copies des images externes sur le disque pour un accès hors ligne.",

    "ai_config_openai_api_label": "API OpenAI",
    "ai_config_openai_api_url_input_placeholder_text": "URL de l'API",
    "ai_config_openai_api_url_input_accessible_description": "URL de l'API OpenAI",
    "ai_config_openai_api_key_input_placeholder_text": "Clé API",
    "ai_config_openai_api_key_input_accessible_description": "Clé de l'API OpenAI",
    "ai_config_openai_api_supported_models_label": "Modèles pris en charge",
    "ai_config_ai_model_names_combo_placeholder_text": "Choisir un modèle",
    "ai_config_ai_model_names_combo_accessible_description": "Modèles pris en charge à choisir",

    "ai_config_base_label": "Paramètres de base",
    "ai_config_base_system_prompt_label": "Invite de système",
    "ai_config_base_system_prompt_edit_placeholder_text": "Invite de système de base qui précède chaque demande",
    "ai_config_base_system_prompt_edit_accessible_description":
        "Invite de système de base qui précède chaque demande. Texte brut.",
    "ai_config_base_response_max_tokens_label": "Nombre maximal de jetons de réponse",
    "ai_config_base_response_max_tokens_input_accessible_description": "Nombre maximal de jetons à recevoir en réponse",
}

==> notolog-1.1.5.tar.gz: notolog-1.1.5/notolog/lexemes/fr/settings_dialog.py <==
# French lexemes settings_dialog.py
lexemes = {
    # Paramètres
    "window_title": "Paramètres",

    "button_close": "Fermer",

    "tab_general": "Général",
    "tab_editor_config": "Éditeur",
    "tab_viewer_config": "Visualiseur",
    "tab_ai_config": "Config IA",

    "general_app_config_label": "Configuration de l'application",
    "general_app_language_label": "Langue",
    "general_app_language_combo_placeholder_text": "Choisir une langue",
    "general_app_language_combo_accessible_description": "Langue de l'interface de l'application",
    "general_app_theme_label": "Thème",
    "general_app_theme_combo_placeholder_text": "Choisir un thème",
    "general_app_theme_combo_accessible_description": "Thème de l'interface de l'application",
    "general_app_default_path_label": "Dossier par défaut pour les notes",
    "general_app_default_path_input_accessible_description": "Spécifiez le dossier par défaut où les notes seront stockées",
    "general_app_default_path_input_placeholder_text": "Sélectionnez ou entrez un chemin de dossier",
    "general_app_elements_visibility_label": "Gérer la visibilité des éléments",
    "general_app_main_menu_label": "Menu Principal",
    "general_app_main_menu_checkbox": "Afficher le menu principal",
    "general_app_main_menu_checkbox_accessible_description": "Afficher le menu déroulant principal de l'application",
    "general_app_font_size_label": "Taille de police : {size}pt",
    "general_app_font_size_slider_accessible_description": "Ajuster la taille de la police globale de l'application",

    "general_statusbar_label": "Barre de statut",
    "general_statusbar_show_global_cursor_position_checkbox": "Afficher la position globale du curseur",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "Afficher la position globale du curseur dans la barre de statut",
    "general_statusbar_show_navigation_arrows_checkbox": "Afficher les flèches de navigation",
    "general_statusbar_show_navigation_arrows_checkbox_accessible_description":
        "Afficher les flèches de navigation dans la barre d'état",

    "editor_config_label": "Configuration de l'éditeur",
    "editor_config_show_line_numbers_checkbox": "Afficher les numéros de ligne",
    "editor_config_show_line_numbers_checkbox_accessible_description": "Afficher les numéros de ligne dans l'éditeur",

    "viewer_config_label": "Configuration du visualiseur",
    "viewer_config_process_emojis_checkbox": "Convertir les emojis de texte en graphiques",
    "viewer_config_process_emojis_checkbox_accessible_description":
        "Convertir les emojis de texte en représentations graphiques",
    "viewer_config_highlight_todos_checkbox": "Mettre en évidence les TODO",
    "viewer_config_highlight_todos_checkbox_accessible_description": "Souligner les balises TODO dans le texte",
    "viewer_config_open_link_confirmation_checkbox": "Demander confirmation avant d'ouvrir les liens",
    "viewer_config_open_link_confirmation_checkbox_accessible_description":
        "Demander une confirmation avant d'ouvrir des liens",
    "viewer_config_save_resources_checkbox": "Enregistrer automatiquement les images externes sur le disque",
    "viewer_config_save_resources_checkbox_accessible_description":
        "Enregistre automatiquement des copies des images externes sur le disque pour un accès hors ligne.",

    "ai_config_inference_module_label": "Module d'inférence",
    "ai_config_inference_module_names_combo_label": "Module d'inférence actif",
    "ai_config_inference_module_names_combo_placeholder_text": "Choisir un module",
    "ai_config_inference_module_names_combo_accessible_description":
        "Sélectionnez parmi les modules d'inférence IA disponibles pour fonctionner avec l'Assistant AI.\n"
        "Les options incluent des modèles de langage de grande taille (LLM) avec traitement en temps réel,\n"
        "ou des fonctionnalités basées sur l'API.",

    "ai_config_base_label": "Paramètres de base",
    "ai_config_multi_turn_dialogue_checkbox": "Dialogue multi-tours avec mémoire conversationnelle",
    "ai_config_multi_turn_dialogue_checkbox_accessible_description":
        "Activez un dialogue multi-tours qui conserve la dernière invite pour une mémoire conversationnelle.\n"
        "Lorsqu'il est désactivé, seuls le nouveau message et l'invite système influencent la réponse.",
    "ai_config_convert_to_md_checkbox": "Convertir le résultat en Markdown",
    "ai_config_convert_to_md_checkbox_accessible_description":
        "Convertissez le message de sortie au format Markdown.",
}
